// Copyright (c) 2009-2017 GeometryFactory (France).
// All rights reserved.
//
// This file is part of CGAL (www.cgal.org).
//
// $URL: https://github.com/CGAL/cgal/blob/v6.0.1/SMDS_3/include/CGAL/IO/facets_in_complex_3_to_triangle_mesh.h $
// $Id: include/CGAL/IO/facets_in_complex_3_to_triangle_mesh.h 50cfbde3b84 $
// SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
//
//
// Author(s)     : Maxime Gimeno,
//                 Mael Rouxel-Labbé

#ifndef CGAL_IO_FACETS_IN_COMPLEX_3_TO_TRIANGLE_MESH_H
#define CGAL_IO_FACETS_IN_COMPLEX_3_TO_TRIANGLE_MESH_H

#include <CGAL/license/SMDS_3.h>

#ifndef CGAL_NO_DEPRECATED_CODE
#include <CGAL/facets_in_complex_3_to_triangle_mesh.h>

#define CGAL_DEPRECATED_HEADER "<CGAL/IO/facets_in_complex_3_to_triangle_mesh.h>"
#define CGAL_REPLACEMENT_HEADER "<CGAL/facets_in_complex_3_to_triangle_mesh.h>"
#include <CGAL/Installation/internal/deprecation_warning.h>
#endif

#endif // CGAL_IO_FACETS_IN_COMPLEX_3_TO_TRIANGLE_MESH_H
